@@ -26,7 +26,13 @@ def auto_conf_generator(args):
         # MinIO
         "minIO_URL" : "spark.hadoop.fs.s3a.endpoint",
         "minIO_ACCESS_KEY" : "spark.hadoop.fs.s3a.access.key",
-        "minIO_SECRET_KEY" : "spark.hadoop.fs.s3a.secret.key" 
+        "minIO_SECRET_KEY" : "spark.hadoop.fs.s3a.secret.key" ,
+        "minIO_URL-input-dataset" : "spark.hadoop.fs.s3a.endpoint",
+        "minIO_ACCESS_KEY-input-dataset" : "spark.hadoop.fs.s3a.access.key",
+        "minIO_SECRET_KEY-input-dataset" : "spark.hadoop.fs.s3a.secret.key",
+        "minIO_URL-output-dataset" : "spark.hadoop.fs.s3a.endpoint",
+        "minIO_ACCESS_KEY-output-dataset" : "spark.hadoop.fs.s3a.access.key",
+        "minIO_SECRET_KEY-output-dataset" : "spark.hadoop.fs.s3a.secret.key"
     }
 
     result = []
